==> haskell-hookup-0.8-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-1BkiLJFUGN0Fuiusgg9P8W
key:                  hookup-0.8-1BkiLJFUGN0Fuiusgg9P8W
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  3d983b52a69b79aab3e646ccad5fa198
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-1BkiLJFUGN0Fuiusgg9P8W
depends:
    HsOpenSSL-0.11.7.8-B1jzBAlnBxy5ppTjDeXqFk
    HsOpenSSL-x509-system-0.1.0.4-CWMBy61BuxDGNYEIwuFLQi
    async-2.2.5-5XCvqKuypO07vwzQefuSFU
    attoparsec-0.14.4-J9YnXPtrDPmCdtF55eYIY2 base-4.16.4.0
    bytestring-0.11.4.0 network-3.1.4.0-9GJKuf6EY6MAL0cwpbhHGu
    stm-2.5.0.2

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hookup-0.8-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-5dQt3lztsurBD36FlojhO4
key:                  hookup-0.8-5dQt3lztsurBD36FlojhO4
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  ada479109895ffef4702c4774ddf6980
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-5dQt3lztsurBD36FlojhO4
depends:
    HsOpenSSL-0.11.7.9-95to1t8ng9v2OAywqUHKaG
    HsOpenSSL-x509-system-0.1.0.4-2umMH5sRe9Q6sL2WS0uoy4
    async-2.2.5-FpYc2RUKqMh7VEhubouhdj
    attoparsec-0.14.4-K2NonRChA499lXmUebatlk base-4.16.4.0
    bytestring-0.11.4.0 network-3.1.4.0-GfG23cgXhomCxCQnvsPNoG
    stm-2.5.0.2

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
